# A simple file sharing service

Upload a file. Share the URL/link. Download the file.

Simple as that.

## Setup development environment

Requirements:
- Java JDK 21
- Gradle 8.5

1. Update `spring.profiles.active` in `application.properties` to `development`
2. Start external Backend and Database
3. Run `./gradlew bootRun ` in the root directory

# Running SharePulse using Docker
```yml
version: '3.8'

services:
  sharepulse:
    image: git.walzen665.de/walzen665/sharepulse:latest
    ports:
      - "80:80"
    environment:
      # All Configurable parameters with default values
      # Can be deleted if default values are used
      RETHINKDB_HOST: rethinkdb
      RETHINKDB_PORT: 28015
      RETHINKDB_DATABASE: sharepulse
      SHAREPULSE_FILEPASSWORD_LENGTH: "6"
      SHAREPULSE_FILEID_LENGTH: "6"
      SHAREPULSE_TEMP_FILESTORE_PATH: "/temp-filestore"
      SHAREPULSE_AUTO_RESET_ON_STARTUP: "true"
      MAX_FILE_SIZE: "1GB"
      MAX_REQUEST_SIZE: "1GB"
    depends_on:
      - rethinkdb
    networks:
      - sharepulse-net

  rethinkdb:
    image: rethinkdb:latest
    volumes:
      - rethinkdb_data:/data
    ports:
      - "28015:28015"
#      - "8080:8080" Webinterface of rethinkdb (optional and only accessible from localhost)
    networks:
      - sharepulse-net

networks:
  sharepulse-net:
    external: false

volumes:
  rethinkdb_data:

```