package de.w665.sharepulse.db.repo;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.rethinkdb.RethinkDB;
import com.rethinkdb.net.Connection;
import de.w665.sharepulse.db.RethinkDBConfig;
import de.w665.sharepulse.db.RethinkDBConnector;
import de.w665.sharepulse.model.User;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;
import java.util.*;

@Repository
public class UserRepository {
    private final RethinkDB r;
    private final Connection connection;
    private final RethinkDBConfig config;
    @Autowired
    public UserRepository(RethinkDBConnector connector, RethinkDBConfig config) {
        this.r = connector.getR();
        this.connection = connector.getConnection();
        this.config = config;
    }

    public Optional<User> retrieveUserByUsername(String username) {
        try {
            User user = r.db(config.getDatabase()).table("users")
                    .filter(r.hashMap("username", username))
                    .run(connection, User.class)
                    .next();
            return Optional.ofNullable(user);
        } catch (NoSuchElementException e) {
            return Optional.empty();
        }
    }

    public void insertUser(User user) {
        r.db(config.getDatabase()).table("users").insert(user).run(connection);
    }
}
