package de.w665.sharepulse.service;

import de.w665.sharepulse.db.repo.FileUploadRepository;
import de.w665.sharepulse.db.repo.ExpiredFileUploadRepository;
import de.w665.sharepulse.model.FileUpload;
import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;

import java.util.List;

@Slf4j
@Service
public class FileCleanupService {

    private final FileUploadRepository fileUploadRepository;
    private final ExpiredFileUploadRepository expiredFileUploadRepository;
    private final FileService fileService;

    public FileCleanupService(FileUploadRepository fileUploadRepository, ExpiredFileUploadRepository expiredFileUploadRepository, FileService fileService) {
        this.fileUploadRepository = fileUploadRepository;
        this.expiredFileUploadRepository = expiredFileUploadRepository;
        this.fileService = fileService;
    }

    @Scheduled(cron = "0 0 * * * *")
    public void cleanup() {
        log.debug("Running cleanup...");
        List<FileUpload> expFileUploads = fileUploadRepository.findAllExpiredActiveFileUploads();
        for (FileUpload fileUpload : expFileUploads) {
            fileService.deleteFile(fileUpload);
            expiredFileUploadRepository.insertExpiredFileUpload(fileUpload);
            log.debug("Moved file " + fileUpload.getFileId() + " to old_file_uploads table.");
        }
    }
}
